Discover Xbox consoles on network
=================================

Discover consoles on your local network.

Usage:
::

    usage: xbox-discover [-h] [--address ADDRESS]

    Discover consoles on the network

    optional arguments:
      -h, --help            show this help message and exit
      --address ADDRESS, -a ADDRESS
                            IP address of console

Example:
::

    xbox-discover

Output:
::

    <Console addr=10.0.0.241 name=XboxOne uuid=011dfd6d-d72d-4e54-8ae1-3b980dc4c21d liveid=FD0034893ß20923E flags=PrimaryDeviceFlag.AllowAnonymousUsers|AllowAuthenticatedUsers>
